@@ -3,7 +3,7 @@
 //  * For the full copyright and license information, please view the LICENSE
 //  * file that was distributed with this source code.
 
-// spell-checker:ignore (ToDO) abcdefghijklmnopqrstuvwxyz efghijklmnopqrstuvwxyz vwxyz emptyfile
+// spell-checker:ignore (ToDO) abcdefghijklmnopqrstuvwxyz efghijklmnopqrstuvwxyz vwxyz emptyfile bogusfile
 
 extern crate tail;
 
@@ -475,3 +475,17 @@ fn test_tail_bytes_for_funny_files() {
             .code_is(exp_result.code());
     }
 }
+
+#[test]
+fn test_no_such_file() {
+    new_ucmd!()
+        .arg("bogusfile")
+        .fails()
+        .no_stdout()
+        .stderr_contains("cannot open 'bogusfile' for reading: No such file or directory");
+}
+
+#[test]
+fn test_no_trailing_newline() {
+    new_ucmd!().pipe_in("x").succeeds().stdout_only("x");
+}
